@@ -31,7 +31,7 @@
 #' d <- tibble(x=c(1,1,2,2), y=c(1,2,1,2))
 #' group_by_all(d, as.factor)
 #' group_by_if(iris, is.factor, as.character)
-group_by_all <- function(.tbl, .funs = list(), ..., .add = FALSE, .drop = group_drops(.tbl)) {
+group_by_all <- function(.tbl, .funs = list(), ..., .add = FALSE, .drop = group_by_drop_default(.tbl)) {
   funs <- manip_all(.tbl, .funs, enquo(.funs), caller_env(), ...)
   if (!length(funs)) {
     funs <- syms(tbl_vars(.tbl))
@@ -40,7 +40,7 @@ group_by_all <- function(.tbl, .funs = list(), ..., .add = FALSE, .drop = group_
 }
 #' @rdname group_by_all
 #' @export
-group_by_at <- function(.tbl, .vars, .funs = list(), ..., .add = FALSE, .drop = group_drops(.tbl)) {
+group_by_at <- function(.tbl, .vars, .funs = list(), ..., .add = FALSE, .drop = group_by_drop_default(.tbl)) {
   funs <- manip_at(.tbl, .vars, .funs, enquo(.funs), caller_env(), .include_group_vars = TRUE, ...)
   if (!length(funs)) {
     funs <- tbl_at_syms(.tbl, .vars, .include_group_vars = TRUE)
@@ -49,7 +49,7 @@ group_by_at <- function(.tbl, .vars, .funs = list(), ..., .add = FALSE, .drop =
 }
 #' @rdname group_by_all
 #' @export
-group_by_if <- function(.tbl, .predicate, .funs = list(), ..., .add = FALSE, .drop = group_drops(.tbl)) {
+group_by_if <- function(.tbl, .predicate, .funs = list(), ..., .add = FALSE, .drop = group_by_drop_default(.tbl)) {
   funs <- manip_if(.tbl, .predicate, .funs, enquo(.funs), caller_env(), .include_group_vars = TRUE, ...)
   if (!length(funs)) {
     funs <- tbl_if_syms(.tbl, .predicate, .include_group_vars = TRUE)
