@@ -44,10 +44,9 @@ top_n <- function(x, n, wt) {
 
   if (quo_is_missing(wt)) {
     vars <- tbl_vars(x)
-    inform(glue("Selecting by ", vars[length(vars)]))
-    wt <- pull(x, -1)
-  } else {
-    wt <- eval_tidy(wt, x)
+    wt_name <- vars[length(vars)]
+    inform(glue("Selecting by ", wt_name))
+    wt <- sym(wt_name)
   }
 
   if (!is_scalar_integerish(n)) {
