@@ -96,23 +96,25 @@ public:
     int pos,
     boost::shared_ptr< DataMaskProxy<SlicedTibble> >& data_mask_proxy
   ) {
-    static Function make_active_binding_fun(
+    static Rcpp::Function make_active_binding_fun(
       ".make_active_binding_fun",
       Rcpp::Environment::namespace_env("dplyr")
     );
 
     // external pointer to the weak proxy of the data mask
     // eventually this calls back to the reak DataMask
-    XPtr< DataMaskWeakProxy<SlicedTibble> > weak_proxy(
+    Rcpp::XPtr< DataMaskWeakProxy<SlicedTibble> > weak_proxy(
       new DataMaskWeakProxy<SlicedTibble>(data_mask_proxy)
     );
 
+    Rcpp::Shield<SEXP> fun(make_active_binding_fun(pos, weak_proxy));
+
     R_MakeActiveBinding(
       // the name of the binding
       symbol,
 
       // the function
-      make_active_binding_fun(pos, weak_proxy),
+      fun,
 
       // where to set it up as an active binding
       mask_active
@@ -128,7 +130,7 @@ public:
   // this is a fairly expensive callback to R, but it only happens
   // when we use the syntax <column> = NULL
   inline void detach(SEXP mask_active, SEXP mask_resolved) {
-    Language("rm", symbol, _["envir"] = mask_active).eval(R_BaseEnv);
+    Rcpp::Language("rm", symbol, Rcpp::_["envir"] = mask_active).eval(R_BaseEnv);
   }
 
 private:
@@ -142,10 +144,10 @@ private:
     SEXP frame = ENCLOS(ENCLOS(mask_resolved));
 
     // materialize
-    Shield<SEXP> value(summary ?
-                       column_subset(data, RowwiseSlicingIndex(indices.group()), frame) :
-                       column_subset(data, indices, frame)
-                      );
+    Rcpp::Shield<SEXP> value(summary ?
+                             column_subset(data, RowwiseSlicingIndex(indices.group()), frame) :
+                             column_subset(data, indices, frame)
+                            );
     MARK_NOT_MUTABLE(value);
 
     // store it in the mask_resolved environment
@@ -224,7 +226,7 @@ public:
   // remove the binding in the mask_active environment
   // so that standard evaluation does not find it
   inline void detach(SEXP mask_active, SEXP mask_resolved) {
-    Language("rm", symbol, _["envir"] = mask_active).eval();
+    Rcpp::Language("rm", symbol, Rcpp::_["envir"] = mask_active).eval();
   }
 
 private:
@@ -280,12 +282,21 @@ public:
   {}
 
   virtual SEXP materialize(int idx) {
-    if (boost::shared_ptr< DataMaskProxy<SlicedTibble> > lock = real.lock()) {
-      return lock.get()->materialize(idx);
-    } else {
-      warning("Hybrid callback proxy out of scope");
-      return R_NilValue;
+    int nprot = 0;
+    SEXP res = R_NilValue;
+    {
+      boost::shared_ptr< DataMaskProxy<SlicedTibble> > lock(real.lock());
+      if (lock) {
+        res = PROTECT(lock.get()->materialize(idx));
+        ++nprot;
+      }
     }
+    if (nprot == 0) {
+      Rcpp::warning("Hybrid callback proxy out of scope");
+    }
+
+    UNPROTECT(nprot);
+    return res;
   }
 };
 
@@ -337,12 +348,12 @@ public:
   // - delays setting up the environment until needed
   DataMask(const SlicedTibble& gdf) :
     column_bindings(),
-    symbol_map(gdf.data().size(), gdf.data().names()),
+    symbol_map(gdf.data()),
     active_bindings_ready(false),
     proxy(new DataMaskProxy<SlicedTibble>(this))
   {
-    const DataFrame& data = gdf.data();
-    CharacterVector names = data.names();
+    const Rcpp::DataFrame& data = gdf.data();
+    Rcpp::Shield<SEXP> names(Rf_getAttrib(data, symbols::names));
     int n = data.size();
     LOG_INFO << "processing " << n << " vars: " << names;
 
@@ -351,7 +362,7 @@ public:
     for (int i = 0; i < n; i++) {
       column_bindings.push_back(
         ColumnBinding<SlicedTibble>(
-          false, SymbolString(names[i]).get_symbol(),
+          false, SymbolString(STRING_ELT(names, i)).get_symbol(),
           data[i]
         )
       );
@@ -381,6 +392,15 @@ public:
     }
   }
 
+  const ColumnBinding<SlicedTibble>*
+  get_subset_binding(int position) const {
+    const ColumnBinding<SlicedTibble>& res = column_bindings[position];
+    if (res.is_null()) {
+      return 0;
+    }
+    return &res;
+  }
+
   // remove this variable from the environments
   void rm(const SymbolString& symbol) {
     int idx = symbol_map.find(symbol);
@@ -416,10 +436,12 @@ public:
   // as we might not need them at all
   void setup() {
     if (!active_bindings_ready) {
+      Rcpp::Shelter<SEXP> shelter;
+
       // the active bindings have not been used at all
       // so setup the environments ...
-      mask_active = child_env(R_EmptyEnv);
-      mask_resolved = child_env(mask_active);
+      mask_active = shelter(child_env(R_EmptyEnv));
+      mask_resolved = shelter(child_env(mask_active));
 
       // ... and install the bindings
       for (size_t i = 0; i < column_bindings.size(); i++) {
@@ -435,13 +457,10 @@ public:
       // top       : the environment containing active bindings.
       //
       // data_mask : where .data etc ... are installed
-      data_mask = rlang::new_data_mask(
-                    mask_resolved, // bottom
-                    mask_active    // top
-                  );
+      data_mask = shelter(rlang::new_data_mask(mask_resolved, mask_active));
 
       // install the pronoun
-      Rf_defineVar(symbols::dot_data, rlang::as_data_pronoun(data_mask), data_mask);
+      Rf_defineVar(symbols::dot_data, shelter(rlang::as_data_pronoun(data_mask)), data_mask);
 
       active_bindings_ready = true;
     } else {
@@ -449,6 +468,11 @@ public:
     }
   }
 
+  SEXP get_data_mask() const {
+    return data_mask;
+  }
+
+
   // get ready to evaluate an R expression for a given group
   // as identified by the indices
   void update(const slicing_index& indices) {
@@ -480,7 +504,6 @@ public:
   //
   //  materialize_binding is defined in utils-bindings.cpp as:
   //
-  // // [[Rcpp::export]]
   // SEXP materialize_binding(
   //   int idx,
   //   XPtr<DataMaskWeakProxyBase> mask_proxy_xp)
@@ -505,8 +528,6 @@ public:
   }
 
   SEXP eval(const Quosure& quo, const slicing_index& indices) {
-    setup();
-
     // update the bindings
     update(indices);
 
@@ -514,15 +535,9 @@ public:
     get_context_env()["..group_size"] = indices.size();
     get_context_env()["..group_number"] = indices.group() + 1;
 
-    SEXP expr = quo.expr();
-    if (TYPEOF(expr) == LANGSXP && Rf_inherits(CAR(expr), "rlang_lambda_function")) {
-      // FIXME: Mutation
-      SET_CLOENV(CAR(expr), mask_resolved) ;
-    }
-
 #if (R_VERSION < R_Version(3, 5, 0))
-    Shield<SEXP> call_quote(Rf_lang2(fns::quote, quo));
-    Shield<SEXP> call_eval_tidy(Rf_lang3(rlang_eval_tidy(), quo, data_mask));
+    Rcpp::Shield<SEXP> call_quote(Rf_lang2(fns::quote, quo));
+    Rcpp::Shield<SEXP> call_eval_tidy(Rf_lang3(rlang_eval_tidy(), quo, data_mask));
 
     return Rcpp::Rcpp_fast_eval(call_eval_tidy, R_BaseEnv);
 #else
@@ -549,9 +564,9 @@ private:
   SymbolMap symbol_map;
 
   // The 3 environments of the data mask
-  Environment mask_active;  // where the active bindings live
-  Environment mask_resolved; // where the resolved active bindings live
-  Environment data_mask; // actual data mask, contains the .data pronoun
+  Rcpp::Environment mask_active;  // where the active bindings live
+  Rcpp::Environment mask_resolved; // where the resolved active bindings live
+  Rcpp::Environment data_mask; // actual data mask, contains the .data pronoun
 
   // are the active bindings ready ?
   bool active_bindings_ready;
@@ -560,8 +575,8 @@ private:
   const slicing_index* current_indices;
 
   // previous values for group_number and group_size
-  RObject previous_group_size;
-  RObject previous_group_number;
+  Rcpp::RObject previous_group_size;
+  Rcpp::RObject previous_group_number;
 
   boost::shared_ptr< DataMaskProxy<SlicedTibble> > proxy;
 
@@ -624,7 +639,7 @@ private:
   }
 
   static SEXP rlang_eval_tidy() {
-    static Language call("::", symbols::rlang, symbols::eval_tidy);
+    static Rcpp::Language call("::", symbols::rlang, symbols::eval_tidy);
     return call;
   }
 
