@@ -2,28 +2,23 @@
 #include <dplyr/main.h>
 
 #include <tools/Quosure.h>
+#include <tools/debug.h>
+#include <tools/bad.h>
 
 #include <dplyr/allow_list.h>
+#include <dplyr/symbols.h>
 
 #include <dplyr/data/GroupedDataFrame.h>
+#include <dplyr/data/DataMask.h>
 
 #include <dplyr/visitors/subset/DataFrameSubsetVisitors.h>
 #include <dplyr/visitors/order/Order.h>
-#include <dplyr/Groups.h>
-#include <tools/bad.h>
 
-#include <dplyr/data/DataMask.h>
-#include <dplyr/symbols.h>
-#include <dplyr/visitors/order/Order.h>
-
-using namespace Rcpp;
-using namespace dplyr;
-
-#include <tools/debug.h>
+namespace dplyr {
 
 template <typename SlicedTibble>
 SEXP arrange_template(const SlicedTibble& gdf, const QuosureList& quosures, SEXP frame) {
-  const DataFrame& data = gdf.data();
+  const Rcpp::DataFrame& data = gdf.data();
   if (data.size() == 0 || data.nrows() == 0)
     return data;
 
@@ -33,8 +28,8 @@ SEXP arrange_template(const SlicedTibble& gdf, const QuosureList& quosures, SEXP
 
   check_valid_colnames(data);
   assert_all_allow_list(data);
-  List variables(nargs);
-  LogicalVector ascending(nargs);
+  Rcpp::List variables(nargs);
+  Rcpp::LogicalVector ascending(nargs);
 
   NaturalDataFrame ndf(data);
   DataMask<NaturalDataFrame> mask(ndf);
@@ -48,7 +43,7 @@ SEXP arrange_template(const SlicedTibble& gdf, const QuosureList& quosures, SEXP
     bool is_desc = TYPEOF(expr) == LANGSXP && symbols::desc == CAR(expr);
     expr = is_desc ? CADR(expr) : expr ;
 
-    RObject v(R_NilValue);
+    Rcpp::RObject v(R_NilValue);
 
     // if expr is a symbol from the data, just use it
     if (TYPEOF(expr) == SYMSXP) {
@@ -59,6 +54,7 @@ SEXP arrange_template(const SlicedTibble& gdf, const QuosureList& quosures, SEXP
     }
 
     // otherwise need to evaluate in the data mask
+    mask.setup();
     if (v.isNULL()) {
       if (is_desc) {
         // we need a new quosure that peels off `desc` from the original
@@ -73,7 +69,7 @@ SEXP arrange_template(const SlicedTibble& gdf, const QuosureList& quosures, SEXP
     }
 
     if (!allow_list(v)) {
-      stop("cannot arrange column of class '%s' at position %d", get_single_class(v), i + 1);
+      Rcpp::stop("cannot arrange column of class '%s' at position %d", get_single_class(v), i + 1);
     }
 
     if (Rf_inherits(v, "data.frame")) {
@@ -82,32 +78,33 @@ SEXP arrange_template(const SlicedTibble& gdf, const QuosureList& quosures, SEXP
       bad_pos_arg(i + 1, "is of unsupported type matrix");
     } else {
       if (Rf_length(v) != data.nrows()) {
-        stop("incorrect size (%d) at position %d, expecting : %d", Rf_length(v), i + 1, data.nrows());
+        Rcpp::stop("incorrect size (%d) at position %d, expecting : %d", Rf_length(v), i + 1, data.nrows());
       }
     }
 
     variables[i] = v;
     ascending[i] = !is_desc;
   }
-  variables.names() = quosures.names();
-
+  Rf_namesgets(variables, quosures.names());
   OrderVisitors o(variables, ascending, nargs);
-  IntegerVector one_based_index = o.apply();
+  Rcpp::IntegerVector one_based_index = o.apply();
 
-  List res = DataFrameSubsetVisitors(data, frame).subset_all(one_based_index);
+  Rcpp::List res = DataFrameSubsetVisitors(data, frame).subset_all(one_based_index);
 
   // let the grouping class organise the rest (the groups attribute etc ...)
   return SlicedTibble(res, gdf).data();
 }
 
-// [[Rcpp::export]]
-SEXP arrange_impl(DataFrame df, QuosureList quosures, SEXP frame) {
-  if (is<RowwiseDataFrame>(df)) {
-    return arrange_template<RowwiseDataFrame>(RowwiseDataFrame(df), quosures, frame);
-  } else if (is<GroupedDataFrame>(df)) {
-    return arrange_template<GroupedDataFrame>(GroupedDataFrame(df), quosures, frame);
+}
+
+// [[Rcpp::export(rng = false)]]
+SEXP arrange_impl(Rcpp::DataFrame df, dplyr::QuosureList quosures, SEXP frame) {
+  if (Rcpp::is<dplyr::RowwiseDataFrame>(df)) {
+    return dplyr::arrange_template<dplyr::RowwiseDataFrame>(dplyr::RowwiseDataFrame(df), quosures, frame);
+  } else if (Rcpp::is<dplyr::GroupedDataFrame>(df)) {
+    return dplyr::arrange_template<dplyr::GroupedDataFrame>(dplyr::GroupedDataFrame(df), quosures, frame);
   } else {
-    return arrange_template<NaturalDataFrame>(NaturalDataFrame(df), quosures, frame);
+    return dplyr::arrange_template<dplyr::NaturalDataFrame>(dplyr::NaturalDataFrame(df), quosures, frame);
   }
 }
 
